
package Paws::SSM::DeleteDocumentResult;
  use Moose;


### main pod documentation begin ###

=head1 NAME

Paws::SSM::DeleteDocumentResult

=head1 ATTRIBUTES



=cut

1;